@@ -23,9 +23,9 @@ for my $my_graph (GD::Graph::bars->new, GD::Graph::hbars->new)
 	x_label         => 'X Label',
 	y_label         => 'Y label',
 	title           => 'Stacked Bars (incremental)',
-	y_max_value     => 50,
-	y_tick_number   => 10,
-	y_label_skip    => 2,
+	#y_max_value     => 50,
+	#y_tick_number   => 10,
+	#y_label_skip    => 2,
 	cumulate        => 1,
 	dclrs           => [ undef, qw(dgreen green) ],
 	borderclrs      => [ undef, qw(black black) ],
